// <copyright file="BytesValue.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

using System;
using System.Text.Json.Serialization;

namespace OpenQA.Selenium.BiDi.Modules.Network;

[JsonPolymorphic(TypeDiscriminatorPropertyName = "type")]
[JsonDerivedType(typeof(StringBytesValue), "string")]
[JsonDerivedType(typeof(Base64BytesValue), "base64")]
public abstract record BytesValue
{
    public static implicit operator BytesValue(string value) => new StringBytesValue(value);
    public static implicit operator BytesValue(byte[] value) => new Base64BytesValue(Convert.ToBase64String(value));
}

public record StringBytesValue(string Value) : BytesValue;

public record Base64BytesValue(string Value) : BytesValue;
